# Djangae

![Pipeline status](https://gitlab.com/potato-oss/djangae/djangae/badges/master/pipeline.svg)

The best way to run Django on Google Cloud.

Djangae (djan-gee) is a Django app that allows you to run Django applications on the Google Cloud platform, including (if you
want to) using Django's models with Google Cloud Datastore as the underlying database.

:earth_africa:&nbsp;&nbsp;[Website](https://djangae.org)&nbsp;&nbsp;|&nbsp;&nbsp;
:computer:&nbsp;&nbsp;[GitLab](https://gitlab.com/potato-oss/djangae/djangae)&nbsp;&nbsp;|&nbsp;&nbsp;
:closed_book:&nbsp;&nbsp; [Docs](https://djangae.readthedocs.io/)&nbsp;&nbsp;|&nbsp;&nbsp;
:busts_in_silhouette:&nbsp;&nbsp;[Google Group](https://groups.google.com/forum/#!forum/djangae-users)

---


# Documentation

[https://djangae.readthedocs.io/](https://djangae.readthedocs.io/)


# Djangae has moved to GitLab

If you're looking at this on GitHub, please note that you're seeing a mirror of the project which now lives on [GitLab](https://gitlab.com/potato-oss/djangae/djangae).


# Contributing to Djangae

See [https://djangae.readthedocs.io/en/latest/contributing/](https://djangae.readthedocs.io/en/latest/contributing/)


# Looking for Commercial Support?

Potato offers Commercial Support for all its Open Source projects and we can tailor a support package to your needs.

If you're interested in commercial support, training, or consultancy then go ahead and contact us at [opensource@potatolondon.com](mailto:opensource@potatolondon.com)


# Come work with Potato

Like Django? So do we! Why not come and work for the company that created Djangae? Check out the [Potato jobs page](https://p.ota.to/jobs/) for our open positions, or reach out to [jobs@p.ota.to](mailto:jobs@p.ota.to).
